# ANL 2025 Official Package
This is the official package for the ANL 2025 competition.


The Automated Negotiating Agent Competition (ANAC) is an international tournament that has been running since 2010 to bring together researchers from the negotiation community. In the Automated Negotiation League (ANL), participants explore the strategies and difficulties in creating efficient agents whose primary purpose is to negotiate with other agent’s strategies. Every year, the league presents a different challenge for the participating agents.

This year’s challenge is: Design and build a negotiation agent for sequential multi-deal negotiation. The agent encounters multiple opponents in sequence and is rewarded for the specific combination of the deals made in each negotiation.

In previous years, ANL focused on different complex negotiation aspects, such as learning from the negotiation history or multilateral agreements, often in the context between two negotiators. This year, we extend to a one-to-many negotiation, specifically sequential bilateral negotiations between a center agent and multiple opponents, one after the other. The center agent is rewarded for the combination of all the agreements that it made with the opponents, taking into account goals such as achieving a target number of products or adhering to budget constraints. Who can build the best strategies to deal with these complex interactions?

ANL 2025 takes place at the IJCAI conference in Montreal, Canada. Winners will be rewarded with funding to join the conference.

Documentation can be found [here](https://autoneg.github.io/anl2025/).

More details about the competition can be found [here](https://anac.cs.brown.edu/anl).

The CFP can be found [here](https://drive.google.com/drive/folders/1xc5qt7XlZQQv6q1NVnu2vP6Ou-YOQUms).
